@@ -1,4 +1,4 @@
-import { is, List, Map, Range, Record, Seq } from 'immutable';
+import { fromJS, is, List, Map, Range, Record, Seq } from 'immutable';
 
 import * as jasmineCheck from 'jasmine-check';
 jasmineCheck.install();
@@ -82,14 +82,14 @@ describe('Map', () => {
 
   it('does not accept strings (collection, but scalar)', () => {
     expect(() => {
-      // @ts-expect-error
+      // @ts-expect-error -- constructor does not accept strings, this is expected to throw
       Map('abc');
     }).toThrow();
   });
 
   it('does not accept non-entries array', () => {
     expect(() => {
-      // @ts-expect-error
+      // @ts-expect-error -- not an array of entries, this is expected to throw
       Map([1, 2, 3]);
     }).toThrow('Expected [K, V] tuple: 1');
   });
@@ -424,6 +424,12 @@ describe('Map', () => {
     expect(is(m1, m2)).toBe(true);
   });
 
+  it('does not equal Record with same values', () => {
+    const m1 = Map({ A: 1, B: 2, C: 3 });
+    const m2 = Record({ A: 1, B: 2, C: 3 });
+    expect(is(m1, m2)).toBe(false);
+  });
+
   it('deletes all the provided keys', () => {
     const NOT_SET = undefined;
     const m1 = Map({ A: 1, B: 2, C: 3 });
@@ -467,6 +473,25 @@ describe('Map', () => {
     expect(m.get(c)).toBe('c');
   });
 
+  it('supports Symbols as object constructor keys', () => {
+    const a = Symbol.for('a');
+    const b = Symbol('b');
+    const c = Symbol('c');
+    const m = Map<symbol, string>({
+      [a]: 'a',
+      [b]: 'b',
+      [c]: 'c',
+    });
+    expect(m.size).toBe(3);
+    expect(m.get(a)).toBe('a');
+    expect(m.get(b)).toBe('b');
+    expect(m.get(c)).toBe('c');
+
+    const m2 = fromJS({ [a]: 'a' }) as Map<symbol, string>;
+    expect(m2.size).toBe(1);
+    expect(m2.get(a)).toBe('a');
+  });
+
   it('Symbol keys are unique', () => {
     const a = Symbol('FooBar');
     const b = Symbol('FooBar');
