@@ -36,7 +36,7 @@ export class Map extends KeyedCollection {
   // @pragma Construction
 
   constructor(value) {
-    return value === null || value === undefined
+    return value === undefined || value === null
       ? emptyMap()
       : isMap(value) && !isOrdered(value)
       ? value
